@@ -22,8 +22,8 @@ logger = logging.getLogger(__name__)
 #     quantity = 1.0
 
 
-@docstr.get_sectionsf('ReactiveTransportSettings',
-                      sections=['Parameters', 'Other Parameters'])
+@docstr.get_sections(base='ReactiveTransportSettings',
+                     sections=['Parameters', 'Other Parameters'])
 @docstr.dedent
 # Uncomment this line when we stop supporting Python 3.6
 # @dataclass
@@ -45,8 +45,6 @@ class ReactiveTransportSettings(GenericSettings):
     ----------------
     sources : list
         List of source terms that have been added
-    variable_props : list
-        List of props that are variable throughout the algorithm
     relaxation_source : float (default = 1.0)
         A relaxation factor to control under-relaxation of the source term.
         Factor approaching 0 leads to improved stability but slower simulation.
@@ -66,6 +64,7 @@ class ReactiveTransportSettings(GenericSettings):
     **The following parameters pertain to the ``GenericTransport`` class**
 
     %(GenericTransportSettings.other_parameters)s
+
     """
 
     nlin_max_iter = 5000
@@ -75,16 +74,13 @@ class ReactiveTransportSettings(GenericSettings):
     # Swap the following 2 lines when we stop supporting Python 3.6
     # sources: List = field(default_factory=lambda: [])
     sources = []
-    # Swap the following 2 lines when we stop supporting Python 3.6
-    variable_props = []
-    # variable_props: List = field(default_factory=lambda: [])
 
 
-@docstr.get_sectionsf('ReactiveTransport', sections=['Parameters'])
+@docstr.get_sections(base='ReactiveTransport', sections=['Parameters'])
 @docstr.dedent
 class ReactiveTransport(GenericTransport):
     r"""
-    A subclass for steady-state simulations with (optionally) source terms
+    A subclass for steady-state simulations with (optional) source terms.
 
     Parameters
     ----------
@@ -92,9 +88,9 @@ class ReactiveTransport(GenericTransport):
 
     Notes
     -----
-
     This subclass performs steady simulations of transport phenomena with
     reactions when source terms are added.
+
     """
 
     def __init__(self, settings={}, phase=None, **kwargs):
@@ -104,15 +100,15 @@ class ReactiveTransport(GenericTransport):
         if phase is not None:
             self.setup(phase=phase)
 
-    @docstr.get_sectionsf('ReactiveTransport.setup',
-                          sections=['Parameters', 'Notes'])
+    @docstr.get_sections(base='ReactiveTransport.setup',
+                         sections=['Parameters', 'Notes'])
     @docstr.dedent
     def setup(self, phase=None, quantity='', conductance='',
               nlin_max_iter=None, relaxation_source=None,
               relaxation_quantity=None, **kwargs):
         r"""
-        This method takes several arguments that are essential to running the
-        algorithm and adds them to the settings
+        This method takes several arguments that are essential to running
+        the algorithm and adds them to the settings.
 
         Parameters
         ----------
@@ -122,11 +118,12 @@ class ReactiveTransport(GenericTransport):
         Notes
         -----
         Under-relaxation is a technique used for improving stability of a
-        computation, particularly in the presence of highly non-linear terms.
-        Under-relaxation used here limits the change in a variable from one
-        iteration to the next. An optimum choice of the relaxation factor is
-        one that is small enough to ensure stable simulation and large enough
-        to speed up the computation.
+        computation, particularly in the presence of highly non-linear
+        terms. Under-relaxation used here limits the change in a variable
+        from one iteration to the next. An optimum choice of the
+        relaxation factor is one that is small enough to ensure stable
+        simulation and large enough to speed up the computation.
+
         """
         if phase:
             self.settings['phase'] = phase.name
@@ -163,7 +160,7 @@ class ReactiveTransport(GenericTransport):
         self[quantity] = x
 
     @docstr.dedent
-    def reset(self, source_terms=False, variable_props=False, **kwargs):
+    def reset(self, source_terms=False, **kwargs):
         r"""
         %(GenericTransport.reset.full_desc)s
 
@@ -172,8 +169,7 @@ class ReactiveTransport(GenericTransport):
         %(GenericTransport.reset.parameters)s
         source_terms : boolean
             If ``True`` removes source terms. The default is ``False``.
-        variable_props : boolean
-            If ``True`` removes variable properties. The default is ``False``.
+
         """
         super().reset(**kwargs)
         if source_terms:
@@ -182,26 +178,30 @@ class ReactiveTransport(GenericTransport):
                 self.pop(item)
             # Reset the settings dict
             self.settings['sources'] = []
-        if variable_props:
-            self.settings['variable_props'] = []
 
-    def set_source(self, propname, pores):
+    def set_source(self, propname, pores, mode='overwrite'):
         r"""
-        Applies a given source term to the specified pores
+        Applies a given source term to the specified pores.
 
         Parameters
         ----------
         propname : string
-            The property name of the source term model to be applied
-
+            The property name of the source term model to be applied.
         pores : array_like
-            The pore indices where the source term should be applied
+            The pore indices where the source term should be applied.
+        mode : str
+            Controls how the sources are applied. Options are:
+
+            'merge' - Adds supplied source term to already existing ones.
+            'overwrite' - (default) Deletes all existing source terms of the
+            given ``propname`` then adds the specified new ones
 
         Notes
         -----
         Source terms cannot be applied in pores where boundary conditions have
         already been set. Attempting to do so will result in an error being
         raised.
+
         """
         locs = self.tomask(pores=pores)
         # Check if any BC is already set in the same locations
@@ -209,38 +209,45 @@ class ReactiveTransport(GenericTransport):
         if (locs & locs_BC).any():
             raise Exception('Boundary conditions already present in given '
                             + 'pores, cannot also assign source terms')
-        # Set source term
-        self[propname] = locs
+        if propname not in self.keys():
+            self[propname] = False
+        if mode == 'merge':
+            self[propname][locs] = True
+        elif mode == 'overwrite':
+            self[propname] = locs
         # Check if propname already in source term list
         if propname not in self.settings['sources']:
             self.settings['sources'].append(propname)
 
-    def _set_variable_props(self, propnames):
+    def remove_source(self, propname, pores=None):
         r"""
-        Inform the algorithm which properties are variable, so those on which
-        they depend will be updated on each solver iteration.
+        Removes source terms from specified pores.
 
         Parameters
         ----------
-        propnames : string or list of strings
-            The propnames of the properties that are variable throughout
-            the algorithm.
+        propname : str
+            The property name of the source term model to be removed.
+        pores : array_like
+            The pore indices where the source term should be applied.
 
         """
-        if isinstance(propnames, str):  # Convert string to list if necessary
-            propnames = [propnames]
-        d = self.settings["variable_props"]
-        self.settings["variable_props"] = list(set(d) | set(propnames))
+        if pores is None:
+            pores = self.Ps
+        locs = self.tomask(pores=pores)
+        if propname not in self.keys():
+            self[propname] = False
+        self[propname][locs] = False
 
     def _update_iterative_props(self):
         """r
-        Update physics using the current value of ``quantity``
+        Update physics using the current value of ``quantity``.
 
         Notes
         -----
-        The algorithm directly writes the value of 'quantity' into the phase.
-        This method was implemented relaxing one of the OpenPNM rules of
-        algorithms not being able to write into phases.
+        The algorithm directly writes the value of 'quantity' into the
+        phase. This method was implemented relaxing one of the OpenPNM
+        rules of algorithms not being able to write into phases.
+
         """
         phase = self.project.phases()[self.settings['phase']]
         physics = self.project.find_physics(phase=phase)
@@ -259,21 +266,23 @@ class ReactiveTransport(GenericTransport):
 
     def _apply_sources(self):
         """r
-        Update ``A`` and ``b`` applying source terms to specified pores
+        Update ``A`` and ``b`` applying source terms to specified pores.
 
         Notes
         -----
-        - Applying source terms to ``A`` and ``b`` is performed after (optionally)
-        under-relaxing the source term to improve numerical stability. Physics
-        are also updated before applying source terms to ensure that source
-        terms values are associated with the current value of 'quantity'.
+        Applying source terms to ``A`` and ``b`` is performed after
+        (optionally) under-relaxing the source term to improve numerical
+        stability. Physics are also updated before applying source terms
+        to ensure that source terms values are associated with the current
+        value of 'quantity'.
 
-        - For source term under-relaxation, old values of S1 and S2 need to be
-        stored somewhere, we chose to store them on the algorithm object. This is
-        because storing them on phase/physics creates unintended problems, ex.
-        storing them on physics -> IO complains added depth to the NestedDict, and
-        storing them on the phase object results in NaNs in case source term is
-        only added to a subset of nodes, which breaks our _check_for_nans algorithm.
+        For source term under-relaxation, old values of S1 and S2 need
+        to be stored somewhere, we chose to store them on the algorithm
+        object. This is because storing them on phase/physics creates
+        unintended problems, ex. storing them on physics -> IO complains
+        added depth to the NestedDict, and storing them on the phase
+        object results in NaNs in case source term is only added to a
+        subset of nodes, which breaks our _check_for_nans algorithm.
 
         Warnings
         --------
@@ -309,29 +318,30 @@ class ReactiveTransport(GenericTransport):
 
     def _run_reactive(self, x0):
         r"""
-        Repeatedly updates ``A``, ``b``, and the solution guess within according
-        to the applied source term then calls ``_solve`` to solve the resulting
-        system of linear equations.
+        Repeatedly updates ``A``, ``b``, and the solution guess within
+        according to the applied source term then calls ``_solve`` to
+        solve the resulting system of linear equations.
 
-        Stops when the residual falls below ``solver_tol * norm(b)`` or when
-        the maximum number of iterations is reached.
+        Stops when the residual falls below ``solver_tol * norm(b)`` or
+        when the maximum number of iterations is reached.
 
         Parameters
         ----------
-        x0 : ND-array
+        x0 : ndarray
             Initial guess of unknown variable
 
         Returns
         -------
-        x : ND-array
+        x : ndarray
             Solution array.
 
         Notes
         -----
-        The algorithm must at least complete one iteration, and hence the check for
-        itr >= 1, because otherwise, _check_for_nans() never get's called in case
-        there's something wrong with the data, and therefore, the user won't get
-        notified about the root cause of the algorithm divergence.
+        The algorithm must at least complete one iteration, and hence the
+        check for itr >= 1, because otherwise, _check_for_nans() never
+        gets called in case there's something wrong with the data, and
+        therefore, the user won't get notified about the root cause of the
+        algorithm divergence.
 
         """
         w = self.settings['relaxation_quantity']
@@ -361,7 +371,8 @@ class ReactiveTransport(GenericTransport):
 
     def _update_A_and_b(self):
         r"""
-        Updates A and b based on the most recent solution stored on algorithm object.
+        Updates A and b based on the most recent solution stored on
+        algorithm object.
         """
         # Update iterative properties on phase, geometries, and physics
         self._update_iterative_props()
@@ -394,10 +405,10 @@ class ReactiveTransport(GenericTransport):
             dg = nx.compose(dg, g.models.dependency_graph(deep=True))
         for p in physics:
             dg = nx.compose(dg, p.models.dependency_graph(deep=True))
-        base_props = [self.settings["quantity"]] + self.settings["variable_props"]
+        base_props = [self.settings["quantity"]]
         if base_props is None:
             return []
-        # Find all props downstream that rely on "quantity" and variable_props
+        # Find all props downstream that rely on "quantity"
         dg = nx.DiGraph(nx.edge_dfs(dg, source=base_props))
         if len(dg.nodes) == 0:
             return []
@@ -412,8 +423,8 @@ class ReactiveTransport(GenericTransport):
     @docstr.dedent
     def _set_BC(self, pores, bctype, bcvalues=None, mode='merge'):
         r"""
-        Apply boundary conditions to specified pores if no source terms are
-        already assigned to these pores. Otherwise, raise an error.
+        Apply boundary conditions to specified pores if no source terms
+        are already assigned to these pores. Otherwise, raise an error.
 
         Parameters
         ----------
@@ -422,12 +433,14 @@ class ReactiveTransport(GenericTransport):
         Notes
         -----
         %(GenericTransport._set_BC.notes)s
+
         """
         # First check that given pores do not have source terms already set
         for item in self.settings['sources']:
             if np.any(self[item][pores]):
-                raise Exception('Source term already present in given '
-                                + 'pores, cannot also assign boundary '
-                                + 'conditions')
+                raise Exception(
+                    'Source term already present in given pores, cannot also'
+                    ' assign boundary conditions'
+                )
         # Then call parent class function if above check passes
         super()._set_BC(pores=pores, bctype=bctype, bcvalues=bcvalues, mode=mode)
