@@ -19,6 +19,9 @@ from . import throat_volume
 from . import throat_capillary_shape_factor
 from . import throat_centroid
 from . import throat_vector
+from . import hydraulic_size_factors
+from . import diffusive_size_factors
+from . import conduit_lengths
 
 # Up for deprecation
 pore_area = pore_cross_sectional_area
